@@ -47,6 +47,13 @@ age_ldv <- function (x, name, a = 1.698, b = -0.2, agemin = 1, agemax = 50, k =
     message(paste("Average age of",name, "is",
                   round(sum(seq(1,agemax)*base::colSums(df)/sum(df)), 2),
                   sep=" "))
+    message(paste("Number of",name, "is",
+                  round(sum(df*k, na.rm = T)/1000, 2),
+                  "* 10^3 veh",
+                  sep=" ")
+    )
+    cat("\n")
+
   } else {
     suca <- function (t) {1 - exp(-exp(a + b*t))}
     anos <- seq(agemin,agemax)
@@ -62,6 +69,13 @@ age_ldv <- function (x, name, a = 1.698, b = -0.2, agemin = 1, agemax = 50, k =
     message(paste("Average age of",name, "is",
                   round(sum(seq(1,agemax)*base::colSums(df)/sum(df)), 2),
                   sep=" "))
+    message(paste("Number of",name, "is",
+                  round(sum(df*k, na.rm = T)/1000, 2),
+                  "* 10^3 veh",
+                  sep=" ")
+    )
+    cat("\n")
+
   }
   df <- Vehicles(df*k)
   return(df)
